==> file-input-1.0.0.tgz: package/index.js <==
function FileInput() {
  if (arguments.length !== 0) {
    throw Error('Invalid arguments');
  }

  var button = document.createElement('button');

  Object.defineProperty(button, 'multiple', multiplePropSpec);
  Object.defineProperty(button, 'accept', acceptPropSpec);
  Object.defineProperty(button, 'files', filesPropSpec);

  button.addEventListener('click', onClick, true);
  button.addEventListener('dragover', onDragOver, true);
  button.addEventListener('drop', onDrop, true);

  button.textContent = 'Choose file';

  button._inputEl = document.createElement('input');
  button._inputEl.type = 'file';
  button._inputEl.addEventListener('change', onFileChosen);
  button._inputEl._owner = button;

  button._multiple = false;
  button._accept = '';
  button._files = button._inputEl.files;

  return button;
}

var multiplePropSpec = {
  get() { return this._multiple; },
  set(value) { this._multiple = Boolean(value); },
};

var acceptPropSpec = {
  get() { return this._accept; },
  set(value) { this._accept = String(value); },
};

var filesPropSpec = {
  get() { return this._files; },
};

function onClick(e) {
  this._inputEl.multiple = this.multiple;
  this._inputEl.accept = this.accept;
  this._inputEl.value = '';
  this._inputEl.click();
}

function onDragOver(e) {
  e.preventDefault();
  e.stopPropagation();

  // We should use .dropEffect to provide feedback on whether the file matches
  // .multiple and .accept, but the browser won't let us test that yet.
  e.dataTransfer.dropEffect = hasFiles(e.dataTransfer) ? 'copy' : 'none';
}

function onDrop(e) {
  e.preventDefault();
  e.stopPropagation();

  var files = e.dataTransfer.files;
  var accept = this.accept;

  if (
    hasFiles(e.dataTransfer) &&
    (this.multiple || files.length === 1) &&
    Array.from(files).every(function (file) {
      return acceptMatches(accept, file);
    })
  ) {
    updateFiles(this, files);
  }
}

function onFileChosen(e) {
  updateFiles(this._owner, this.files);
}

function hasFiles(dataTransfer) {
  // Cannot use dataTransfer.files, that is not populated until the drop event
  return Array.prototype.indexOf.call(dataTransfer.types, 'Files') !== -1;
}

function acceptMatches(accept, file) {
  if (accept === '') return true;

  var parts = accept.split(',');

  for (var i = 0; i < parts.length; i++) {
    var part = parts[i].trim();

    if (part === 'audio/*' || part === 'video/*' || part === 'image/*') {
      // MIME type wildcard match
      if (file.type.slice(0, 6) === part.slice(0, 6)) return true;
    } else if (part.charAt(0) === '.') {
      // File extension match
      if (file.name.match(/\.[^.]*$/)[0] === part) return true;
    } else {
      // MIME type match
      if (file.type === part) return true;
    }
  }
  return false;
}

function updateFiles(fileInput, files) {
  fileInput._files = files;
  fileInput.dispatchEvent(new CustomEvent('change'));
}

export default FileInput;

==> file-input-3.0.0.tgz: package/index.js <==
'use strict';

function FileInput() {
  if (!(arguments.length === 0)) {
    throw Error('Must receive no arguments');
  }

  const button = document.createElement('button');

  Object.defineProperty(button, 'multiple', multiplePropSpec);
  Object.defineProperty(button, 'accept', acceptPropSpec);
  Object.defineProperty(button, 'files', filesPropSpec);

  button.addEventListener('click', onClick, true);
  button.addEventListener('dragover', onDragOver, true);
  button.addEventListener('drop', onDrop, true);

  button.textContent = 'Choose file';

  button._inputEl = document.createElement('input');
  button._inputEl.type = 'file';
  button._inputEl.addEventListener('change', onFileChosen);
  button._inputEl._owner = button;

  button._multiple = false;
  button._accept = '';
  button._files = button._inputEl.files;

  return button;
}

const multiplePropSpec = {
  get() { return this._multiple; },
  set(value) { this._multiple = Boolean(value); },
};

const acceptPropSpec = {
  get() { return this._accept; },
  set(value) { this._accept = String(value); },
};

const filesPropSpec = {
  get() { return this._files; },
};

function onClick(e) {
  this._inputEl.multiple = this.multiple;
  this._inputEl.accept = this.accept;
  this._inputEl.value = '';
  this._inputEl.click();
}

function onDragOver(e) {
  e.preventDefault();
  e.stopPropagation();

  // Ideally we would also show "none" if the dataTransfer doesn't match
  // .multiple and .accept, but the browser doesn't make that information
  // available yet.
  e.dataTransfer.dropEffect = hasFiles(e.dataTransfer) ? 'copy' : 'none';
}

function onDrop(e) {
  e.preventDefault();
  e.stopPropagation();

  const files = e.dataTransfer.files;

  if (
    hasFiles(e.dataTransfer) &&
    (this.multiple || files.length === 1) &&
    Array.from(files).every(file => acceptMatches(this.accept, file))
  ) {
    updateFiles(this, files);
  }
}

function onFileChosen(e) {
  updateFiles(this._owner, this.files);
}

function hasFiles(dataTransfer) {
  // Cannot use dataTransfer.files, that is not populated until the drop event
  return Array.prototype.indexOf.call(dataTransfer.types, 'Files') !== -1;
}

function acceptMatches(accept, file) {
  if (accept === '') return true;

  const parts = accept.split(',');

  for (let i = 0; i < parts.length; i++) {
    const part = parts[i].trim();

    if (part === 'audio/*' || part === 'video/*' || part === 'image/*') {
      // MIME type wildcard match
      if (file.type.slice(0, 6) === part.slice(0, 6)) return true;
    } else if (part.charAt(0) === '.') {
      // File extension match
      if (file.name.match(/\.[^.]*$/)[0] === part) return true;
    } else {
      // MIME type match
      if (file.type === part) return true;
    }
  }
  return false;
}

function updateFiles(fileInput, files) {
  fileInput._files = files;
  fileInput.dispatchEvent(new CustomEvent('change'));
}

module.exports = FileInput;
